@@ -6,6 +6,7 @@ import (
 	"path/filepath"
 	"strconv"
 	"strings"
+	"sync"
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
@@ -60,8 +61,12 @@ func (s *GitStatus) add(code string) {
 }
 
 const (
+	// DisableWithJJ disables the git segment when there's a .jj directory in the parent file path
+	DisableWithJJ properties.Property = "disable_with_jj"
 	// FetchStatus fetches the status of the repository
 	FetchStatus properties.Property = "fetch_status"
+	// FetchPushStatus fetches the push-remote status
+	FetchPushStatus properties.Property = "fetch_push_status"
 	// IgnoreStatus allows to ignore certain repo's for status information
 	IgnoreStatus properties.Property = "ignore_status"
 	// FetchWorktreeCount fetches the worktree count
@@ -125,6 +130,7 @@ const (
 	GITCOMMAND   = "git"
 
 	trueStr = "true"
+	origin  = "origin"
 )
 
 type Rebase struct {
@@ -135,25 +141,30 @@ type Rebase struct {
 }
 
 type Git struct {
-	User           *User
+	configErr      error
+	config         *ini.File
 	Working        *GitStatus
 	Staging        *GitStatus
 	commit         *Commit
 	Rebase         *Rebase
-	RawUpstreamURL string
-	Ref            string
-	Hash           string
+	User           *User
 	ShortHash      string
+	Hash           string
 	BranchStatus   string
 	Upstream       string
 	HEAD           string
 	UpstreamIcon   string
 	UpstreamURL    string
+	Ref            string
+	RawUpstreamURL string
 	Scm
-	worktreeCount int
 	stashCount    int
-	Behind        int
 	Ahead         int
+	PushAhead     int
+	PushBehind    int
+	Behind        int
+	worktreeCount int
+	configOnce    sync.Once
 	IsWorkTree    bool
 	Merge         bool
 	CherryPick    bool
@@ -200,11 +211,12 @@ func (g *Git) Enabled() bool {
 	}
 
 	if displayStatus {
-		g.setGitStatus()
-		g.setGitHEADContext()
+		g.setStatus()
+		g.setHEADStatus()
 		g.setBranchStatus()
+		g.setPushStatus()
 	} else {
-		g.setHEADName()
+		g.updateHEADReference()
 	}
 
 	if g.props.GetBool(FetchUpstreamIcon, false) {
@@ -316,7 +328,7 @@ func (g *Git) Kraken() string {
 
 	if g.RawUpstreamURL == "" {
 		if g.Upstream == "" {
-			g.Upstream = "origin"
+			g.Upstream = origin
 		}
 		g.RawUpstreamURL = g.getRemoteURL()
 	}
@@ -333,6 +345,13 @@ func (g *Git) LatestTag() string {
 }
 
 func (g *Git) shouldDisplay() bool {
+	// Check if disable_with_jj is enabled and .jj directory exists
+	if g.props.GetBool(DisableWithJJ, false) {
+		if _, err := g.env.HasParentFilePath(".jj", false); err == nil {
+			return false
+		}
+	}
+
 	gitdir, err := g.env.HasParentFilePath(".git", true)
 	if err != nil {
 		return false
@@ -384,13 +403,7 @@ func (g *Git) isBareRepo(gitDir *runtime.FileInfo) bool {
 		g.mainSCMDir = filepath.Join(gitDir.ParentFolder, dir)
 	}
 
-	configData := g.fileContent(g.mainSCMDir, "config")
-	if configData == "" {
-		log.Debug("Git config file not found, not a bare repo")
-		return false
-	}
-
-	cfg, err := ini.Load([]byte(configData))
+	cfg, err := g.getGitConfig()
 	if err != nil {
 		log.Error(err)
 		return false
@@ -529,6 +542,92 @@ func (g *Git) setBranchStatus() {
 	g.BranchStatus = getBranchStatus()
 }
 
+func (g *Git) setPushStatus() {
+	if !g.props.GetBool(FetchPushStatus, false) {
+		return
+	}
+
+	if g.Ref == "" || g.Ref == DETACHED {
+		return
+	}
+
+	pushRemote := g.getPushRemote()
+	if pushRemote == "" {
+		return
+	}
+
+	ahead := g.getGitCommandOutput("rev-list", "--count", pushRemote+"..HEAD")
+	if ahead != "" {
+		g.PushAhead, _ = strconv.Atoi(strings.TrimSpace(ahead))
+	}
+
+	behind := g.getGitCommandOutput("rev-list", "--count", "HEAD.."+pushRemote)
+	if behind != "" {
+		g.PushBehind, _ = strconv.Atoi(strings.TrimSpace(behind))
+	}
+}
+
+func (g *Git) getPushRemote() string {
+	upstream := g.Upstream
+	if idx := strings.Index(upstream, "/"); idx != -1 {
+		upstream = upstream[:idx]
+	}
+
+	if upstream == "" {
+		upstream = origin
+	}
+
+	branch := g.Ref
+	if branch == "" {
+		return ""
+	}
+
+	cfg, err := g.getGitConfig()
+	if err != nil {
+		pushRemote := g.getGitCommandOutput("config", "--get", "remote.pushDefault")
+		if pushRemote == "" {
+			pushRemote = upstream
+		}
+
+		return strings.TrimSpace(pushRemote) + "/" + branch
+	}
+
+	sectionName := fmt.Sprintf(`branch "%s"`, branch)
+	section := cfg.Section(sectionName)
+	pushRemote := section.Key("pushRemote").String()
+	if pushRemote == "" {
+		pushRemote = cfg.Section("remote").Key("pushDefault").String()
+	}
+
+	if pushRemote == "" {
+		pushRemote = upstream
+	}
+
+	return pushRemote + "/" + branch
+}
+
+func (g *Git) getGitConfig() (*ini.File, error) {
+	g.configOnce.Do(func() {
+		configData := g.fileContent(g.mainSCMDir, "config")
+		if configData == "" {
+			log.Debug("git config file not found")
+			g.configErr = fmt.Errorf("git config file not found")
+			return
+		}
+
+		// ini.Load expects []byte to parse content, not a file path
+		cfg, err := ini.Load([]byte(configData))
+		if err != nil {
+			g.configErr = err
+			return
+		}
+
+		g.config = cfg
+	})
+
+	return g.config, g.configErr
+}
+
 func (g *Git) cleanUpstreamURL(url string) string {
 	// Azure DevOps
 	if strings.Contains(url, "dev.azure.com") {
@@ -614,7 +713,7 @@ func (g *Git) getUpstreamIcon() string {
 	return g.props.GetString(GitIcon, "\uE5FB ")
 }
 
-func (g *Git) setGitStatus() {
+func (g *Git) setStatus() {
 	addToStatus := func(status string) {
 		const UNTRACKED = "?"
 		if strings.HasPrefix(status, UNTRACKED) {
@@ -713,18 +812,18 @@ func (g *Git) getGitCommandOutput(args ...string) string {
 	return val
 }
 
-func (g *Git) setGitHEADContext() {
+func (g *Git) setHEADStatus() {
 	branchIcon := g.props.GetString(BranchIcon, "\uE0A0")
 	if g.Ref == DETACHED {
 		g.Detached = true
-		g.setHEADName()
+		g.resolveDetachedHEAD()
 	} else {
 		head := g.formatBranch(g.Ref)
 		g.HEAD = fmt.Sprintf("%s%s", branchIcon, head)
 	}
 
 	formatDetached := func() string {
-		if g.Ref == DETACHED {
+		if g.Detached {
 			return fmt.Sprintf("%sdetached at %s", branchIcon, g.HEAD)
 		}
 		return g.HEAD
@@ -870,25 +969,53 @@ func (g *Git) getGitRefFileSymbolicName(refFile string) string {
 	return g.getGitCommandOutput("name-rev", "--name-only", "--exclude=tags/*", ref)
 }
 
-func (g *Git) setHEADName() {
-	// we didn't fetch status, fallback to parsing the HEAD file
-	if g.ShortHash == "" {
-		HEADRef := g.fileContent(g.mainSCMDir, "HEAD")
-		g.Detached = !strings.HasPrefix(HEADRef, "ref:")
-		if after, ok := strings.CutPrefix(HEADRef, BRANCHPREFIX); ok {
-			branchName := after
-			g.Ref = branchName
-			g.HEAD = fmt.Sprintf("%s%s", g.props.GetString(BranchIcon, "\uE0A0"), g.formatBranch(branchName))
+func (g *Git) updateHEADReference() {
+	HEADRef := g.fileContent(g.mainSCMDir, "HEAD")
+	log.Debug("HEADRef:", HEADRef)
+
+	// check if we are in a repo using reftables
+	if HEADRef == "ref: refs/heads/.invalid" {
+		log.Debug("repo is using reftables")
+
+		HEADRef = g.getGitCommandOutput("rev-parse", "--symbolic-full-name", "HEAD")
+
+		// this is a detached head
+		if strings.HasPrefix(HEADRef, "fatal:") {
+			log.Debug("detached HEAD detected")
+			g.Detached = true
+			g.resolveDetachedHEAD()
 			return
 		}
-		// no branch, points to commit
-		if len(HEADRef) >= 7 {
-			g.ShortHash = HEADRef[0:7]
-			g.Hash = HEADRef[0:]
-			g.Ref = g.ShortHash
+
+		if strings.HasPrefix(HEADRef, "refs/heads/") {
+			HEADRef = "ref: " + HEADRef
 		}
+
+		log.Debug("resolved HEADRef:", HEADRef)
 	}
 
+	g.Detached = !strings.HasPrefix(HEADRef, "ref:")
+	if branchName, ok := strings.CutPrefix(HEADRef, BRANCHPREFIX); ok {
+		log.Debug("current HEAD is a branch:", branchName)
+
+		g.Ref = branchName
+		g.HEAD = fmt.Sprintf("%s%s", g.props.GetString(BranchIcon, "\uE0A0"), g.formatBranch(branchName))
+
+		return
+	}
+
+	g.resolveDetachedHEAD()
+}
+
+func (g *Git) resolveDetachedHEAD() {
+	HEADRef := g.getGitCommandOutput("rev-parse", "HEAD")
+
+	if len(HEADRef) >= 7 {
+		g.ShortHash = HEADRef[0:7]
+		g.Hash = HEADRef[0:]
+	}
+	g.Ref = g.ShortHash
+
 	// check for tag
 	tagName := g.getGitCommandOutput("describe", "--tags", "--exact-match")
 	if len(tagName) > 0 {
@@ -897,7 +1024,7 @@ func (g *Git) setHEADName() {
 		return
 	}
 
-	// fallback to commit
+	// fallback to no commits found
 	if g.ShortHash == "" {
 		g.HEAD = g.props.GetString(NoCommitsIcon, "\uF594 ")
 		return
@@ -931,10 +1058,10 @@ func (g *Git) WorktreeCount() int {
 func (g *Git) getRemoteURL() string {
 	upstream := regex.ReplaceAllString("/.*", g.Upstream, "")
 	if upstream == "" {
-		upstream = "origin"
+		upstream = origin
 	}
 
-	cfg, err := ini.Load(g.scmDir + "/config")
+	cfg, err := g.getGitConfig()
 	if err != nil {
 		return g.getGitCommandOutput("remote", "get-url", upstream)
 	}
@@ -951,9 +1078,7 @@ func (g *Git) getRemoteURL() string {
 func (g *Git) Remotes() map[string]string {
 	var remotes = make(map[string]string)
 
-	location := filepath.Join(g.scmDir, "config")
-	config := g.env.FileContent(location)
-	cfg, err := ini.Load([]byte(config))
+	cfg, err := g.getGitConfig()
 	if err != nil {
 		return remotes
 	}
