@@ -15,19 +15,19 @@ import (
 
 func TestPythonTemplate(t *testing.T) {
 	type ResolveSymlink struct {
-		Path string
 		Err  error
+		Path string
 	}
 	cases := []struct {
+		ResolveSymlink   ResolveSymlink
 		Case             string
 		Expected         string
-		ExpectedDisabled bool
 		Template         string
 		VirtualEnvName   string
-		FetchVersion     bool
 		PythonPath       string
-		ResolveSymlink   ResolveSymlink
 		PyvenvCfg        string
+		ExpectedDisabled bool
+		FetchVersion     bool
 	}{
 		{Case: "No virtual env present", FetchVersion: true, Expected: "3.8.4", Template: "{{ if .Venv }}{{ .Venv }} {{ end }}{{ .Full }}"},
 		{Case: "Virtual env present", FetchVersion: true, Expected: "VENV 3.8.4", VirtualEnvName: "VENV", Template: "{{ if .Venv }}{{ .Venv }} {{ end }}{{ .Full }}"},
@@ -123,8 +123,8 @@ func TestPythonTemplate(t *testing.T) {
 
 func TestPythonPythonInContext(t *testing.T) {
 	cases := []struct {
-		Expected       bool
 		VirtualEnvName string
+		Expected       bool
 	}{
 		{Expected: true, VirtualEnvName: "VENV"},
 		{Expected: false, VirtualEnvName: ""},
@@ -151,8 +151,8 @@ func TestPythonPythonInContext(t *testing.T) {
 func TestPythonVirtualEnvIgnoreDefaultVenvNames(t *testing.T) {
 	cases := []struct {
 		Expected           string
-		FolderNameFallback bool
 		VirtualEnvName     string
+		FolderNameFallback bool
 	}{
 		{
 			Expected:           "folder",
@@ -198,3 +198,48 @@ func TestPythonVirtualEnvIgnoreDefaultVenvNames(t *testing.T) {
 		assert.Equal(t, tc.Expected, python.Venv)
 	}
 }
+
+func TestPythonVirtualEnvIgnoreCustomVenvNames(t *testing.T) {
+	cases := []struct {
+		Expected           string
+		VirtualEnvName     string
+		DefaultVenvNames   []string
+		FolderNameFallback bool
+	}{
+		{
+			Expected:           "folder",
+			FolderNameFallback: true,
+			DefaultVenvNames:   []string{"env"},
+			VirtualEnvName:     "/path/to/folder/env",
+		},
+		{
+			Expected:           "venv",
+			FolderNameFallback: true,
+			DefaultVenvNames:   []string{"env"},
+			VirtualEnvName:     "/path/to/folder/venv",
+		},
+	}
+
+	for _, tc := range cases {
+		params := &mockedLanguageParams{}
+		env, props := getMockedLanguageEnv(params)
+
+		env.On("GOOS").Return("")
+		env.On("PathSeparator").Return("/")
+		env.On("CommandPath", testify_.Anything).Return("")
+		env.On("HasFilesInDir", testify_.Anything, "pyvenv.cfg").Return(false)
+		env.On("Getenv", "VIRTUAL_ENV").Return(tc.VirtualEnvName)
+		env.On("Getenv", "CONDA_ENV_PATH").Return("")
+		env.On("Getenv", "CONDA_DEFAULT_ENV").Return("")
+		env.On("Getenv", "PYENV_VERSION").Return("")
+		env.On("HasParentFilePath", ".python-version", false).Return(&runtime.FileInfo{}, errors.New("no match at root level"))
+
+		props[FolderNameFallback] = tc.FolderNameFallback
+		props[DefaultVenvNames] = tc.DefaultVenvNames
+
+		python := &Python{}
+		python.Init(props, env)
+		python.loadContext()
+		assert.Equal(t, tc.Expected, python.Venv)
+	}
+}
